==> kpopup-0.2.0.tar.gz: kpopup-0.2.0/kpopup/make_popup.h <==
/***************************************************************************
                          make_popup.h  -  description
                          ----------------------------
    begin                : Sun Feb 20 2000
    copyright            : (C) 2000 by Torsten Henschel
    email                : henschel@fh-brandenburg.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include <kapp.h>

#include <qcombobox.h>
#include <qdialog.h>
#include <qlabel.h>
#include <qmultilinedit.h>
#include <qpushbutton.h>

class make_Popup : public QDialog
{
 Q_OBJECT

 public:
        make_Popup(QWidget *parent, const char *name);

        void ReadBrowseList();
//        void ReadConfigHosts();
        void ReadHostName();
//        void SaveConfigHosts(const char *host);

        QPushButton *B_Ok;
        QPushButton *B_Cancel;
        QMultiLineEdit *MLE_Text;
        QLabel *L_Receiver;
        QLabel *L_Text;
        QLabel *L_User;
        QComboBox *CB_Receiver;
        QLineEdit *LE_User;

 public slots:
              void SendPopup();

 private:
          KConfig *config;
};

==> kpopup-0.3.1.tar.gz: kpopup-0.3.1/kpopup/make_popup.h <==
/***************************************************************************
                          make_popup.h  -  description
                          ----------------------------
    copyright            : (C) 2000 by Torsten Henschel
    email                : henschel@fh-brandenburg.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include <kapp.h>

#include <qcombobox.h>
#include <qdialog.h>
#include <qlabel.h>
#include <qmultilinedit.h>
#include <qpushbutton.h>

class make_Popup : public QDialog
{
 Q_OBJECT

 public:
        make_Popup(QWidget *parent, const char *name);
        ~make_Popup();
        void ReadBrowseList();
        void ReadHostName();

        QPushButton *B_Ok;
        QPushButton *B_Cancel;
        QMultiLineEdit *MLE_Text;
        QLabel *L_Receiver;
        QLabel *L_Text;
        QLabel *L_User;
        QComboBox *CB_Receiver;

 public slots:
              void SendPopup();

 private:
         char *hostname;
};
